==> jc-1.4.0.tar.gz: java/util/Arrays__24ArrayList.h <==
// final class java.util.Arrays$ArrayList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 4a2b9f35d0d4bf7d java_util_Arrays__24ArrayList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_java_util_Arrays__24ArrayList_H_
#define _JC_java_util_Arrays__24ArrayList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_util_Arrays__24ArrayList$sub_refs	_jc_java_util_Arrays__24ArrayList$sub_refs;
typedef struct _jc_java_util_Arrays__24ArrayList$sub_nonrefs	_jc_java_util_Arrays__24ArrayList$sub_nonrefs;
typedef struct _jc_java_util_Arrays__24ArrayList$refs	_jc_java_util_Arrays__24ArrayList$refs;
typedef struct _jc_java_util_Arrays__24ArrayList$nonrefs	_jc_java_util_Arrays__24ArrayList$nonrefs;
typedef struct _jc_java_util_Arrays__24ArrayList$object	_jc_java_util_Arrays__24ArrayList$object;

typedef struct _jc_java_util_Arrays__24ArrayList$fields_struct	_jc_java_util_Arrays__24ArrayList$fields_struct;
typedef const struct _jc_java_util_Arrays__24ArrayList$vmethods	_jc_java_util_Arrays__24ArrayList$vmethods;
typedef const struct _jc_java_util_Arrays__24ArrayList$vtable	_jc_java_util_Arrays__24ArrayList$vtable;
typedef const struct _jc_java_util_Arrays__24ArrayList$vtype	_jc_java_util_Arrays__24ArrayList$vtype;

// Class fields structure
struct _jc_java_util_Arrays__24ArrayList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Arrays__24ArrayList$fields_struct _jc_java_util_Arrays__24ArrayList$class_fields;

// Constructors
extern void _jc_java_util_Arrays__24ArrayList$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_object_array *);

// Virtual methods
extern jboolean _jc_java_util_Arrays__24ArrayList$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Arrays__24ArrayList$method$get$a706240e1333824b(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint);
extern jint _jc_java_util_Arrays__24ArrayList$method$indexOf$59e53868af339edb(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Arrays__24ArrayList$method$lastIndexOf$af030ff733adf0f9(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Arrays__24ArrayList$method$set$21145a3aa89a3e6d(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Arrays__24ArrayList$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *);
extern _jc_object_array *_jc_java_util_Arrays__24ArrayList$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *);
extern _jc_object_array *_jc_java_util_Arrays__24ArrayList$method$toArray$b7264a1d378ca224(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$get$a706240e1333824b;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$indexOf$59e53868af339edb;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$lastIndexOf$af030ff733adf0f9;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$set$21145a3aa89a3e6d;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$toArray$408321282fd84959;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$toArray$b7264a1d378ca224;

// Virtual methods structure
struct _jc_java_util_Arrays__24ArrayList$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint);
	jint	(*indexOf$59e53868af339edb)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *);
	jint	(*lastIndexOf$af030ff733adf0f9)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*set$21145a3aa89a3e6d)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint, struct _jc_java_lang_Object$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *);
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *);
	_jc_object_array	*(*toArray$b7264a1d378ca224)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_java_util_Arrays__24ArrayList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_Arrays__24ArrayList$vmethods	java_util_Arrays__24ArrayList;
};

// Vtype
struct _jc_java_util_Arrays__24ArrayList$vtype {
	_jc_type			type;
	_jc_java_util_Arrays__24ArrayList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Arrays__24ArrayList$sub_refs {
	_jc_object_array	*a;
};

// Reference instance fields (object)
struct _jc_java_util_Arrays__24ArrayList$refs {
    _jc_java_util_Arrays__24ArrayList$sub_refs	java_util_Arrays__24ArrayList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Arrays__24ArrayList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Arrays__24ArrayList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_Arrays__24ArrayList$sub_nonrefs	java_util_Arrays__24ArrayList;
};

// Object instance structure
struct _jc_java_util_Arrays__24ArrayList$object {
	_jc_java_util_Arrays__24ArrayList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Arrays__24ArrayList$vtype	*vtype;
	_jc_java_util_Arrays__24ArrayList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Arrays__24ArrayList$vtype _jc_java_util_Arrays__24ArrayList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Arrays__24ArrayList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Arrays__24ArrayList$class_object;

#endif	/* _JC_java_util_Arrays__24ArrayList_H_ */

==> jc-1.4.6.tar.gz: java/util/Arrays__24ArrayList.h <==
// final class java.util.Arrays$ArrayList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 4a2b9f35d0d4bf7d java_util_Arrays__24ArrayList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_java_util_Arrays__24ArrayList_H_
#define _JC_java_util_Arrays__24ArrayList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_util_Arrays__24ArrayList$sub_refs	_jc_java_util_Arrays__24ArrayList$sub_refs;
typedef struct _jc_java_util_Arrays__24ArrayList$sub_nonrefs	_jc_java_util_Arrays__24ArrayList$sub_nonrefs;
typedef struct _jc_java_util_Arrays__24ArrayList$refs	_jc_java_util_Arrays__24ArrayList$refs;
typedef struct _jc_java_util_Arrays__24ArrayList$nonrefs	_jc_java_util_Arrays__24ArrayList$nonrefs;
typedef struct _jc_java_util_Arrays__24ArrayList$object	_jc_java_util_Arrays__24ArrayList$object;

typedef struct _jc_java_util_Arrays__24ArrayList$fields_struct	_jc_java_util_Arrays__24ArrayList$fields_struct;
typedef const struct _jc_java_util_Arrays__24ArrayList$vmethods	_jc_java_util_Arrays__24ArrayList$vmethods;
typedef const struct _jc_java_util_Arrays__24ArrayList$vtable	_jc_java_util_Arrays__24ArrayList$vtable;
typedef const struct _jc_java_util_Arrays__24ArrayList$vtype	_jc_java_util_Arrays__24ArrayList$vtype;

// Class fields structure
struct _jc_java_util_Arrays__24ArrayList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Arrays__24ArrayList$fields_struct _jc_java_util_Arrays__24ArrayList$class_fields;

// Constructors
extern void _jc_java_util_Arrays__24ArrayList$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Arrays__24ArrayList$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Arrays__24ArrayList$method$get$a706240e1333824b(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_java_util_Arrays__24ArrayList$method$indexOf$59e53868af339edb(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Arrays__24ArrayList$method$lastIndexOf$af030ff733adf0f9(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Arrays__24ArrayList$method$set$21145a3aa89a3e6d(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Arrays__24ArrayList$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_util_Arrays__24ArrayList$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_util_Arrays__24ArrayList$method$toArray$b7264a1d378ca224(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$get$a706240e1333824b;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$indexOf$59e53868af339edb;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$lastIndexOf$af030ff733adf0f9;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$set$21145a3aa89a3e6d;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$toArray$408321282fd84959;
extern _jc_method _jc_java_util_Arrays__24ArrayList$method_info$toArray$b7264a1d378ca224;

// Virtual methods structure
struct _jc_java_util_Arrays__24ArrayList$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint) _JC_JCNI_ATTR;
	jint	(*indexOf$59e53868af339edb)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*lastIndexOf$af030ff733adf0f9)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*set$21145a3aa89a3e6d)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*toArray$b7264a1d378ca224)(_jc_env *, struct _jc_java_util_Arrays__24ArrayList$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Arrays__24ArrayList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_Arrays__24ArrayList$vmethods	java_util_Arrays__24ArrayList;
};

// Vtype
struct _jc_java_util_Arrays__24ArrayList$vtype {
	_jc_type			type;
	_jc_java_util_Arrays__24ArrayList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Arrays__24ArrayList$sub_refs {
	_jc_object_array	*a;
};

// Reference instance fields (object)
struct _jc_java_util_Arrays__24ArrayList$refs {
    _jc_java_util_Arrays__24ArrayList$sub_refs	java_util_Arrays__24ArrayList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Arrays__24ArrayList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Arrays__24ArrayList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_Arrays__24ArrayList$sub_nonrefs	java_util_Arrays__24ArrayList;
};

// Object instance structure
struct _jc_java_util_Arrays__24ArrayList$object {
	_jc_java_util_Arrays__24ArrayList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Arrays__24ArrayList$vtype	*vtype;
	_jc_java_util_Arrays__24ArrayList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Arrays__24ArrayList$vtype _jc_java_util_Arrays__24ArrayList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Arrays__24ArrayList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Arrays__24ArrayList$class_object;

#endif	/* _JC_java_util_Arrays__24ArrayList_H_ */
